@@ -1,6 +1,7 @@
 package operator
 
 import (
+	"context"
 	"fmt"
 	"time"
 
@@ -9,11 +10,12 @@ import (
 	utilnet "k8s.io/apimachinery/pkg/util/net"
 	"k8s.io/apimachinery/pkg/util/wait"
 	"k8s.io/client-go/util/retry"
-	"k8s.io/klog"
+	"k8s.io/klog/v2"
 
 	imageregistryv1 "github.com/openshift/api/imageregistry/v1"
 	regopset "github.com/openshift/client-go/imageregistry/clientset/versioned/typed/imageregistry/v1"
-	"github.com/openshift/cluster-image-registry-operator/pkg/parameters"
+
+	"github.com/openshift/cluster-image-registry-operator/pkg/defaults"
 )
 
 func (c *Controller) RemoveResources(o *imageregistryv1.Config) error {
@@ -28,7 +30,7 @@ func (c *Controller) finalizeResources(o *imageregistryv1.Config) error {
 
 	finalizers := []string{}
 	for _, v := range o.ObjectMeta.Finalizers {
-		if v != parameters.ImageRegistryOperatorResourceFinalizer {
+		if v != defaults.ImageRegistryOperatorResourceFinalizer {
 			finalizers = append(finalizers, v)
 		}
 	}
@@ -55,13 +57,15 @@ func (c *Controller) finalizeResources(o *imageregistryv1.Config) error {
 		if cr == nil {
 			// Skip using the cache here so we don't have as many
 			// retries due to slow cache updates
-			cr, err := client.Configs().Get(o.Name, metav1.GetOptions{})
+			cr, err := client.Configs().Get(
+				context.TODO(), o.Name, metav1.GetOptions{},
+			)
 			if err != nil {
 				return fmt.Errorf("failed to get %s: %s", utilObjectInfo(o), err)
 			}
 			finalizers = []string{}
 			for _, v := range cr.ObjectMeta.Finalizers {
-				if v != parameters.ImageRegistryOperatorResourceFinalizer {
+				if v != defaults.ImageRegistryOperatorResourceFinalizer {
 					finalizers = append(finalizers, v)
 				}
 			}
@@ -69,7 +73,9 @@ func (c *Controller) finalizeResources(o *imageregistryv1.Config) error {
 
 		cr.ObjectMeta.Finalizers = finalizers
 
-		_, err := client.Configs().Update(cr)
+		_, err := client.Configs().Update(
+			context.TODO(), cr, metav1.UpdateOptions{},
+		)
 		if err != nil {
 			cr = nil
 			return err
