@@ -130,6 +130,17 @@ func makePodTemplateSpec(coreClient coreset.CoreV1Interface, proxyLister configl
 		}
 	}
 
+	// If the storage driver is asking for specific volumes to be mounted in,
+	// then ensure we redeploy on a change.
+	for _, vol := range volumes {
+		if vol.Secret != nil {
+			deps.AddSecret(vol.Secret.SecretName)
+		}
+		if vol.ConfigMap != nil {
+			deps.AddConfigMap(vol.ConfigMap.Name)
+		}
+	}
+
 	clusterProxy, err := proxyLister.Get(defaults.ClusterProxyResourceName)
 	if errors.IsNotFound(err) {
 		clusterProxy = &configapiv1.Proxy{}
@@ -235,6 +246,17 @@ func makePodTemplateSpec(coreClient coreset.CoreV1Interface, proxyLister configl
 		corev1.EnvVar{Name: "REGISTRY_HTTP_TLS_KEY", Value: "/etc/secrets/tls.key"},
 	)
 
+	volumes = append(volumes, corev1.Volume{
+		Name: "ca-trust-extracted",
+		VolumeSource: corev1.VolumeSource{
+			EmptyDir: &corev1.EmptyDirVolumeSource{},
+		},
+	})
+	mounts = append(mounts, corev1.VolumeMount{
+		Name:      "ca-trust-extracted",
+		MountPath: "/etc/pki/ca-trust/extracted",
+	})
+
 	// Registry certificate authorities - mount as high-priority trust source anchors
 	vol = corev1.Volume{
 		Name: "registry-certificates",
@@ -307,6 +329,32 @@ func makePodTemplateSpec(coreClient coreset.CoreV1Interface, proxyLister configl
 	)
 	deps.AddSecret(defaults.InstallationPullSecret)
 
+	// Project the ServiceAccount token into the Pod (for Pod-identity authentication cases).
+	saVol := corev1.Volume{
+		Name: "bound-sa-token",
+		VolumeSource: corev1.VolumeSource{
+			Projected: &corev1.ProjectedVolumeSource{
+				Sources: []corev1.VolumeProjection{
+					{
+						ServiceAccountToken: &corev1.ServiceAccountTokenProjection{
+							Audience: "openshift",
+							Path:     "token",
+						},
+					},
+				},
+			},
+		},
+	}
+	volumes = append(volumes, saVol)
+
+	saMount := corev1.VolumeMount{
+		Name: saVol.Name,
+		// Default (by convention) location for mounting projected ServiceAccounts
+		MountPath: "/var/run/secrets/openshift/serviceaccount",
+		ReadOnly:  true,
+	}
+	mounts = append(mounts, saMount)
+
 	image := os.Getenv("IMAGE")
 
 	resources := corev1.ResourceRequirements{
@@ -362,6 +410,11 @@ func makePodTemplateSpec(coreClient coreset.CoreV1Interface, proxyLister configl
 				{
 					Name:  "registry",
 					Image: image,
+					Command: []string{
+						"/bin/sh",
+						"-c",
+						"mkdir -p /etc/pki/ca-trust/extracted/edk2 /etc/pki/ca-trust/extracted/java /etc/pki/ca-trust/extracted/openssl /etc/pki/ca-trust/extracted/pem && update-ca-trust extract && exec /usr/bin/dockerregistry",
+					},
 					Ports: []corev1.ContainerPort{
 						{
 							ContainerPort: int32(defaults.ContainerPort),
